@@ -147,7 +147,9 @@ class PhRTPython3(PhRTBase):
                             .replace('$timeout', str(self.timeout)) \
                             .replace('$user', os.getenv('USER', 'unknown')) \
                             .replace('$group', self.group) \
-                            .replace('$ide', self.ide)
+                            .replace('$ide', self.ide) \
+                            .replace('$access_key', os.getenv('AWS_ACCESS_KEY_ID', "NULL")) \
+                            .replace('$secret_key', os.getenv('AWS_SECRET_ACCESS_KEY', "NULL"))
                 file.write(line)
 
     def create(self, **kwargs):
